==> numerous-image-tools-1.0.0a13.tar.gz: numerous-image-tools-1.0.0a13/setup.py <==
import setuptools
import os
from distutils.util import convert_path
from pathlib import Path

def package_files(basedir):
    paths = []
    for (path, directories, filenames) in os.walk(basedir):
        for filename in filenames:
            Path(path)
            paths.append("/".join([Path(path).relative_to(Path(basedir)).as_posix(),filename]))
    return paths

root = Path(os.getcwd().replace('\\', '/').replace(" ", "%20"))

local_package_dir = root / Path("local_packages_to_be_removed")

ver_path = convert_path('version.txt')
ver=None
if os.path.exists(ver_path):
    with open(ver_path) as ver_file:
        ver=ver_file.read()

packages = setuptools.find_packages()
packages.append('numerous_cli')
packages.append('numerous_api_client')



setuptools.setup(
    name="numerous-image-tools",
    version=ver,
    author='Tobias Dokkedal Elmoee, EnergyMachines ApS',
    author_email='tobias.dokkedal.elmoe@energymachines.com',
    description="Numerous platform image tools",
    long_description="",
    long_description_content_type="text/markdown",
    url="",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
    packages=packages,
    package_dir={'numerous_cli': 'local_packages_to_be_removed/command_line',
                 'numerous_api_client': 'local_packages_to_be_removed/api_client'},
    package_data = {'numerous_cli': package_files('local_packages_to_be_removed/command_line'),
                    'numerous_api_client': package_files('local_packages_to_be_removed/api_client')},

    include_package_data=True,

    #package_data = {'local_packages_to_be_removed': ['./testis/*']},
    install_requires=[
        f"numerous_api_client @ file://localhost/{local_package_dir.as_posix()}/api_client/",
        'api_grpc @ https://pypi.numerously.com/packages/api_grpc-0.2.tar.gz#md5=f866de36eaa8bbd1316d1d7cb913089b',
        'client_common @ https://pypi.numerously.com/packages/client_common-0.1.tar.gz#md5=601a39af74ab7447373995ecd73d24f4',
        'dirtools_numerous @ https://pypi.numerously.com/packages/dirtools_numerous-0.2.1.tar.gz#md5=e62af7ef614c2be38eb293d129f26d73',
        f"numerous_cli @ file://localhost/{local_package_dir.as_posix()}/command_line/",
    ],

    python_requires='>=3.9',
)

==> numerous-image-tools-2.1.0.tar.gz: numerous-image-tools-2.1.0/setup.py <==
import setuptools
import os
from distutils.util import convert_path
from pathlib import Path

def package_files(basedir):
    paths = []
    for (path, directories, filenames) in os.walk(basedir):
        for filename in filenames:
            paths.append("/".join([Path(path).relative_to(Path(basedir)).as_posix(),filename]))
    return paths

root = Path(os.getcwd().replace('\\', '/').replace(" ", "%20"))

local_package_dir = root / Path("local_packages_to_be_removed")

ver_path = convert_path('version.txt')
ver=None
if os.path.exists(ver_path):
    with open(ver_path) as ver_file:
        ver=ver_file.read()

packages = setuptools.find_packages()
packages.append('numerous_cli')

setuptools.setup(
    name="numerous-image-tools",
    version=ver,
    author='Tobias Dokkedal Elmoee, EnergyMachines ApS',
    author_email='tobias.dokkedal.elmoe@energymachines.com',
    description="Numerous platform image tools",
    long_description="",
    long_description_content_type="text/markdown",
    url="",
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: BSD License",
        "Operating System :: OS Independent",
    ],
    packages=packages,
    package_dir={'numerous_cli': 'local_packages_to_be_removed/command_line/src/numerous_cli'},
    package_data = {'numerous_cli': package_files('local_packages_to_be_removed/command_line/src')},
    #                'numerous_api_client': package_files('local_packages_to_be_removed/api_client/src')},
    include_package_data=True,
    #package_data = {'local_packages_to_be_removed': ['./testis/*']},
    install_requires=[
        'numerous_api_client @ https://pypi.numerously.com/packages/numerous_api_client-0.11.0b1.tar.gz#md5=bcab5264f29a4fba6eabb5726f072e22',
        'api_grpc @ https://pypi.numerously.com/packages/api_grpc-0.3.tar.gz#md5=5df53976f72e02874ba310f77cbc58fb',
        'client_common @ https://pypi.numerously.com/packages/client_common-0.1.tar.gz#md5=601a39af74ab7447373995ecd73d24f4',
        'dirtools_numerous @ https://pypi.numerously.com/packages/dirtools_numerous-0.2.1.tar.gz#md5=e62af7ef614c2be38eb293d129f26d73',
        "grpc-interceptor==0.13.0", "grpcio==1.42.0", "numpy==1.21.4", "protobuf==3.19.1",
                        "pytz==2021.3", "requests==2.26.0", "scipy==1.7.3", "str2bool==1.1",
                        "colorama==0.4.4", "prettytable==2.4.0", "ipywidgets==7.7.0", "plotly==5.6.0",

        f"numerous_cli @ file://localhost/{local_package_dir.as_posix()}/command_line/",
    ],
    dependency_links=[
        'https://pypi.numerously.com/simple/'
    ],

    python_requires='>=3.9',
)
